(* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Routine importing the tables with number of degrees of freedom used for the
energy and entropy densities

Input:
choice - "const" or "filename" of table in "./src/<filename>" with
          columns {T[GeV],heff,Sqrt[geff],Sqrt[g*]}
Output:
iheff[T]        = heff (temperature[GeV])
isqrtgeff[T]    = Sqrt[geff] (temperature[GeV])
isqrtgstar[T]   = Sqrt[g*] (temperature[GeV])
gtilde[T]

Version: 12-10-2020
Contact: Andrzej Hryczuk (NCBJ)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% *)

dofimport[choice_] := Module[{tmp,tH,ts},
  Clear[iheff, isqrtgstar, isqrtgeff,H,s]; (* clear definitions *)
  If[choice == "const",
   (* if assumption of const heff,geff,gstar; note these are functions not
   InterpolationFunctions, but with the same syntax *)
    iheff[T_]      := Rationalize[10.2^2];
    isqrtgeff[T_]  := Rationalize[10.2];
    isqrtgstar[T_] := Rationalize[10.2];

    H[T_] := Pi/(3 Sqrt[10]) isqrtgeff[T] T^2/MPl; (* Hubble rate *)
    s[T_] := iheff[T] (2 \[Pi]^2)/45 T^3;          (* entropy density *)

    (* in this case gtilde =0 *)
    gtilde[T_] = 0;
   ,

   (* if tabulated values *)
   tmp=Drop[Import[choice],1]; (* import file without the headline *)

    theff       = tmp[[All, {1, 2}]];
    tsqrtgeff   = tmp[[All, {1, 3}]];
    tsqrtgstar  = tmp[[All, {1, 4}]];

    (* interpolations *)
    isqrtgstar  = Interpolation[tsqrtgstar];
    isqrtgeff   = Interpolation[tsqrtgeff];
    iheff       = Interpolation[theff];

    tH = tsqrtgeff/.{T_,y_}:>{T, Pi/(3 Sqrt[10])/MPl(* =1.35978*10^-19*) T^2 y};
    H  = Interpolation[tH];          (* Hubble rate *)
    ts = theff/.{T_,y_}:>{T, (2 Pi^2)/45(* =0.438649*) T^3 y};
    s  = Interpolation[ts];          (* entropy density *)

    (* construct gtilde *)
    gtilde[T_] := T/3 iheff'[T]/iheff[T];
   ]
];
